/**
 * Copyright (c) Microsoft Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import path from 'path';
import { Page } from './page';
import * as api from '../../types/types';

export class Video implements api.Video {
  private _page: Page;
  private _pathCallback: ((path: string) => void) | undefined;
  private _pathPromise: Promise<string>;

  constructor(page: Page) {
    this._page = page;
    this._pathPromise = new Promise(f => this._pathCallback = f);
  }

  _setRelativePath(relativePath: string) {
    this._pathCallback!(path.join(this._page.context()._options.recordVideo!.dir, relativePath));
  }

  path(): Promise<string> {
    return this._pathPromise;
  }
}
